@@ -23,7 +23,7 @@
 #' @param force (logical) force download? Default: \code{FALSE}
 #' We use a cached version (an .rds compressed file) if it exists, but
 #' this will override that behavior.
-#' @param ... Curl options passed on to \code{\link[httr]{GET}}
+#' @param ... Curl options passed on to \code{\link[crul]{HttpClient}}
 #'
 #' @references ftp://ftp.ncdc.noaa.gov/pub/data/noaa/
 #' @family isd
@@ -99,14 +99,11 @@
 #' system.time( isd(usaf="782680", wban="99999", year=2011) )
 #' system.time( isd(usaf="782680", wban="99999", year=2011) )
 #'
-#' # Optionally pass in curl options
-#' res <- isd(usaf="011490", wban="99999", year=1986, config = verbose())
-#'
 #' # Plot data
 #' ## get data for multiple stations
 #' res1 <- isd(usaf="011690", wban="99999", year=1993)
-#' res2 <- isd(usaf="172007", wban="99999", year=2015)
-#' res3 <- isd(usaf="702700", wban="00489", year=2015)
+#' res2 <- isd(usaf="782680", wban="99999", year=2011)
+#' res3 <- isd(usaf="008415", wban="99999", year=2016)
 #' res4 <- isd(usaf="109711", wban=99999, year=1970)
 #' ## combine data
 #' library(dplyr)
@@ -156,10 +153,9 @@ isd <- function(usaf, wban, year, overwrite = TRUE, cleanup = TRUE,
 isd_GET <- function(bp, usaf, wban, year, overwrite, ...) {
   dir.create(bp, showWarnings = FALSE, recursive = TRUE)
   fp <- isd_local(usaf, wban, year, bp, ".gz")
+  cli <- crul::HttpClient$new(isd_remote(usaf, wban, year), opts = list(...))
   tryget <- tryCatch(
-    suppressWarnings(
-      httr::GET(isd_remote(usaf, wban, year), httr::write_disk(fp, overwrite), ...)
-    ),
+    suppressWarnings(cli$get(disk = fp)),
     error = function(e) e
   )
   if (inherits(tryget, "error")) {
