@@ -3,10 +3,11 @@
 #' The \emph{meteo} functions use an aplication
 #'
 #' @note This function will clear all cached \emph{meteo} files.
+#' @param force (logical) force delete. default: \code{FALSE}
 #' @family meteo
 #' @export
-meteo_clear_cache <- function() {
-  files <- list.files(rnoaa_cache_dir, full.names = TRUE)
+meteo_clear_cache <- function(force = FALSE) {
+  files <- list.files(file.path(rnoaa_cache_dir(), "ghcnd"), full.names = TRUE)
   unlink(files, recursive = TRUE, force = force)
 }
 
@@ -17,6 +18,5 @@ meteo_clear_cache <- function() {
 #' @family meteo
 #' @export
 meteo_show_cache <- function() {
-  cat(rnoaa_cache_dir, "\n")
+  cat(file.path(rnoaa_cache_dir(), "ghcnd"), "\n")
 }
-
